==> mgb-0.6.7.tar.bz2: language/lang_schweizerdeutsch_utf8/lang_main.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ==================================== //
	// lang_main.php - Schweizerdeutsch 1.2 //
	// ==================================== //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// strings of index.php
	$lang['install_directory_exists'] = "De Ordner 'install' isch nonig gl&ouml;scht worde !!.<br>Da das es Sicherheitsrisiko isch, sett de gl&ouml;scht werde !<br>Vergiss aber n&ouml;d nacheme Update zerscht <a href=\"install/upgrade.php\" title=\"Upgrade\">upgrade.php</a> uszf&uuml;ere!";
	$lang['new_entry'] = "Itrag schribe";
	$lang['new_entry_descr'] = "Da chamer en eigene neue Itrag schribe";
	$lang['contact'] = "Kontakt";
	$lang['contact_descr'] = "Mit em G&auml;schtebuechbetriber Kontakt ufn&auml;";
	$lang['adminpanel'] = "Adminischtration";
	$lang['adminpanel_descr'] = "Zum Login";
	$lang['entry'] = "Itrag";
	$lang['entries'] = "Itr&auml;g";
	$lang['no_entries'] = "Es sind leider no kei Itr&auml;g vorhande";
	$lang['entries_on_pages'] = "Itr&auml;g uf {PAGES} Sitene";
	$lang['page_first'] = "Uf di erschti Site";
	$lang['page_first_symbol'] = "&laquo;";
	$lang['page_forwards'] = "Zu de n&auml;chschte Site";
	$lang['page_forwards_symbol'] = "&rsaquo;";
	$lang['page_last'] = "Zu de letschte Site";
	$lang['page_last_symbol'] = "&raquo;";
	$lang['page_backwards'] = "Zu de vorherige Site ga";
	$lang['page_backwards_symbol'] = "&lsaquo;";
	$lang['anchor'] = "Zu dem Itrag gumpe";
	$lang['from'] = "us";
	$lang['at'] = "bi dere";
	$lang['oclock'] = "Zit";
	$lang['comment'] = "Kommentar";
	$lang['email_yes'] = "eMail vo {ENTRY_NAME}";
	$lang['email_no'] = "{ENTRY_NAME} will kei eMails &uuml;bers G&auml;schtebuech.";
	$lang['hp_of'] = "Internetsite vo {ENTRY_NAME}";
	$lang['gravatar'] = "Gravatar von {ENTRY_NAME}";

	// strings of newentry.php
	$lang['name'] = "Din Name:";
	$lang['city'] = "Dis Wohnort:";
	$lang['email'] = "Dis eMail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['homepage'] = "Internetsite:";
	$lang['message'] = "Dini Nachricht:";
	$lang['necessary_fields'] = "[ Pflichtf&auml;lder sind mit eme Stern (*) kennzeichnet ]";
	$lang['user_notification'] = "Mit eme eMail benachrichtige, wenn de Itrag freig&auml;, oder en Kommentar dazue geschriebe worde isch.";
	$lang['user_show_email'] = "Erlaub andere Teilnehmer dir es eMail &uuml;bers Kontaktformular z'schribe. Mini eMail-Adr&auml;sse wird aber so oder so n&ouml;d azeigt.";
	$lang['send'] = "Itrag schribe";
	$lang['preview'] = "Vorschau";
	$lang['errormessage1'] = "Aso ohni en Itrag-Text bringt das n&uuml;t!";
	$lang['errormessage2'] = "Es mues e g&uuml;ltigi eMail-Adr&auml;sse ig&auml; werde!";
	$lang['errormessage3'] = "Es mues en Name ig&auml; werde!";
	$lang['errormessage4'] = "Das isch kei g&uuml;ltigi<br>eMail Adr&auml;sse!";
	$lang['errormessage5'] = "ist keine g&uuml;ltige<br>ICQ Nummer!";
	$lang['errormessage6'] = "D'IP-Sperre verb&uuml;tet en neue Itrag!";
	$lang['errormessage7'] = "De Sicherheitscode isch falsch oder n&ouml;d ig&auml;&auml; worde!";
	$lang['errormessage8'] = "D&auml; M&auml;nsch will kei eMail empfange!";
	$lang['errormessage9'] = "Es isch en Fehler bim eMail-Versand uftr&auml;te!";
	$lang['errormessage10'] = "Spamschutz: Das Formular wurde zu schnell abgesendet. Bitte warte noch {TIME_LOCK_REST} Sekunden.";
	$lang['security_code'] = "Sicherheitscode";
	$lang['captcha_what_is_that'] = "Was isch das?";
	$lang['captcha_wikipedia'] = "http://de.wikipedia.org/wiki/Captcha";
	$lang['captcha_tooltip'] = " En neue Itrag erfordered d'Igab vome Sicherheitscode zum automatisierte Itr&auml;g zvermide. <b>Gib all Buechstabe i Gross-Schrift i</b> Isch de Code n&ouml;d l&auml;sbar, Klick ohni igab uf Itr&auml;ge, d&auml;nn wird en neue Code azeigt.";
	$lang['back_to_mainpage'] = "Zrugg zu de Haubtsite";
	$lang['back'] = "Zrugg";
	$lang['entry_success_mod'] = "De Itrag isch gschpeichered worde, de Admin wird en beguetachte und den w&auml;ner ok isch freischalte.";
	$lang['entry_success'] = "De Itrag isch gschpeichered und isch jetz Online.";
	$lang['forwarding'] = "Si werdet i 5 Sekunde automatisch witergeleitet. W&auml;nn n&ouml;d, den klicked Si bitte uf ''Zrugg zu de Haubtsite''.";
	$lang['bbcodes'] = "BBCodes:";
	$lang['bbcode_help_bold'] = "Fett";
	$lang['bbcode_help_italic'] = "Kursiv";
	$lang['bbcode_help_url'] = "Link";
	$lang['bbcode_textsize'] = "Schriftgr&ouml;ssi";
	$lang['bbcode_extrasmall'] = "Winzig";
	$lang['bbcode_small'] = "Chli";
	$lang['bbcode_default'] = "Standard";
	$lang['bbcode_big'] = "Gross;";
	$lang['bbcode_extrabig'] = "Riesig";
	$lang['bbcode_textcolor'] = "Schriftfarb";
	$lang['bbcode_help_size'] = "Schriftgr&ouml;ssi";
	$lang['smileys'] = "Smilies:";
	$lang['sendmail_admin_title'] = "Neue G&auml;stebuechitrag vo '{NAME}'";
	$lang['sendmail_user_title'] = "Ihre Itrag auf {DOMAIN}";

	// strings of email.php
	$lang['email_name'] = "Ihre Name:";
	$lang['email_email'] = "Ihres eMail:";
	$lang['email_message'] = "Ihri Nachricht:";
	$lang['email_sent_to'] = "Die eMail wird gschickt a:";
	$lang['email_send'] = "Abs&auml;nde";
	$lang['email_caption'] = "eMail von '{NAME}' &uuml;ber das G&auml;stebuch von {DOMAIN}";
	$lang['email_sender'] = "Absender:";
	$lang['email_receiver'] = "Empf&auml;nger:";
	$lang['email_from'] = "&uuml;ber:";
	$lang['email_sendcopytome'] = "Ich m&ouml;chti e Kopie vo dem eMail &uuml;bercho.";
	$lang['email_success'] = "Ihri eMail isch erfolgrich a de Benutzer verschickt worde.";
	$lang['email_fail'] = "Die eMail h&auml;t n&ouml;d verschickt werde ch&ouml;ne. M&ouml;glicherwis git's es Problem mit em Mailserver.";
?>

==> mgb-0.6.7.1.tar.bz2: language/lang_schweizerdeutsch_utf8/lang_main.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ==================================== //
	// lang_main.php - Schweizerdeutsch 1.2 //
	// ==================================== //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// strings of index.php
	$lang['install_directory_exists'] = "De Ordner 'install' isch nonig gl&ouml;scht worde !!.<br>Da das es Sicherheitsrisiko isch, sett de gl&ouml;scht werde !<br>Vergiss aber n&ouml;d nacheme Update zerscht <a href=\"install/upgrade.php\" title=\"Upgrade\">upgrade.php</a> uszf&uuml;ere!";
	$lang['new_entry'] = "Itrag schribe";
	$lang['new_entry_descr'] = "Da chamer en eigene neue Itrag schribe";
	$lang['contact'] = "Kontakt";
	$lang['contact_descr'] = "Mit em G&auml;schtebuechbetriber Kontakt ufn&auml;";
	$lang['adminpanel'] = "Adminischtration";
	$lang['adminpanel_descr'] = "Zum Login";
	$lang['entry'] = "Itrag";
	$lang['entries'] = "Itr&auml;g";
	$lang['no_entries'] = "Es sind leider no kei Itr&auml;g vorhande";
	$lang['entries_on_pages'] = "Itr&auml;g uf {PAGES} Sitene";
	$lang['page_first'] = "Uf di erschti Site";
	$lang['page_first_symbol'] = "&laquo;";
	$lang['page_forwards'] = "Zu de n&auml;chschte Site";
	$lang['page_forwards_symbol'] = "&rsaquo;";
	$lang['page_last'] = "Zu de letschte Site";
	$lang['page_last_symbol'] = "&raquo;";
	$lang['page_backwards'] = "Zu de vorherige Site ga";
	$lang['page_backwards_symbol'] = "&lsaquo;";
	$lang['anchor'] = "Zu dem Itrag gumpe";
	$lang['from'] = "us";
	$lang['at'] = "bi dere";
	$lang['oclock'] = "Zit";
	$lang['comment'] = "Kommentar";
	$lang['email_yes'] = "eMail vo {ENTRY_NAME}";
	$lang['email_no'] = "{ENTRY_NAME} will kei eMails &uuml;bers G&auml;schtebuech.";
	$lang['hp_of'] = "Internetsite vo {ENTRY_NAME}";
	$lang['gravatar'] = "Gravatar von {ENTRY_NAME}";

	// strings of newentry.php
	$lang['name'] = "Din Name:";
	$lang['city'] = "Dis Wohnort:";
	$lang['email'] = "Dis eMail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['homepage'] = "Internetsite:";
	$lang['message'] = "Dini Nachricht:";
	$lang['necessary_fields'] = "[ Pflichtf&auml;lder sind mit eme Stern (*) kennzeichnet ]";
	$lang['user_notification'] = "Mit eme eMail benachrichtige, wenn de Itrag freig&auml;, oder en Kommentar dazue geschriebe worde isch.";
	$lang['user_show_email'] = "Erlaub andere Teilnehmer dir es eMail &uuml;bers Kontaktformular z'schribe. Mini eMail-Adr&auml;sse wird aber so oder so n&ouml;d azeigt.";
	$lang['user_accept_akismet_service'] = "Dieser Eintrag wird durch 'Akismet' auf Spam überprüft. Ich bin mir bewusst, dass wenn ich den Eintrag absende, persönliche Daten von mir auf einen Server in die USA geschickt werden, und akzeptiere dies.";
	$lang['send'] = "Itrag schribe";
	$lang['preview'] = "Vorschau";
	$lang['errormessage1'] = "Aso ohni en Itrag-Text bringt das n&uuml;t!";
	$lang['errormessage2'] = "Es mues e g&uuml;ltigi eMail-Adr&auml;sse ig&auml; werde!";
	$lang['errormessage3'] = "Es mues en Name ig&auml; werde!";
	$lang['errormessage4'] = "Das isch kei g&uuml;ltigi<br>eMail Adr&auml;sse!";
	$lang['errormessage5'] = "ist keine g&uuml;ltige<br>ICQ Nummer!";
	$lang['errormessage6'] = "D'IP-Sperre verb&uuml;tet en neue Itrag!";
	$lang['errormessage7'] = "De Sicherheitscode isch falsch oder n&ouml;d ig&auml;&auml; worde!";
	$lang['errormessage8'] = "D&auml; M&auml;nsch will kei eMail empfange!";
	$lang['errormessage9'] = "Es isch en Fehler bim eMail-Versand uftr&auml;te!";
	$lang['errormessage10'] = "Spamschutz: Das Formular wurde zu schnell abgesendet. Bitte warte noch {TIME_LOCK_REST} Sekunden.";
	$lang['errormessage11'] = "Die Akismet-Einverständniserklärung wurde nicht akzeptiert.<br>Um den Eintrag übernehmen zu können, muss sie akzeptiert werden.";
	$lang['security_code'] = "Sicherheitscode";
	$lang['captcha_what_is_that'] = "Was isch das?";
	$lang['captcha_wikipedia'] = "http://de.wikipedia.org/wiki/Captcha";
	$lang['captcha_tooltip'] = " En neue Itrag erfordered d'Igab vome Sicherheitscode zum automatisierte Itr&auml;g zvermide. <b>Gib all Buechstabe i Gross-Schrift i</b> Isch de Code n&ouml;d l&auml;sbar, Klick ohni igab uf Itr&auml;ge, d&auml;nn wird en neue Code azeigt.";
	$lang['back_to_mainpage'] = "Zrugg zu de Haubtsite";
	$lang['back'] = "Zrugg";
	$lang['entry_success_mod'] = "De Itrag isch gschpeichered worde, de Admin wird en beguetachte und den w&auml;ner ok isch freischalte.";
	$lang['entry_success'] = "De Itrag isch gschpeichered und isch jetz Online.";
	$lang['forwarding'] = "Si werdet i 5 Sekunde automatisch witergeleitet. W&auml;nn n&ouml;d, den klicked Si bitte uf ''Zrugg zu de Haubtsite''.";
	$lang['bbcodes'] = "BBCodes:";
	$lang['bbcode_help_bold'] = "Fett";
	$lang['bbcode_help_italic'] = "Kursiv";
	$lang['bbcode_help_url'] = "Link";
	$lang['bbcode_textsize'] = "Schriftgr&ouml;ssi";
	$lang['bbcode_extrasmall'] = "Winzig";
	$lang['bbcode_small'] = "Chli";
	$lang['bbcode_default'] = "Standard";
	$lang['bbcode_big'] = "Gross;";
	$lang['bbcode_extrabig'] = "Riesig";
	$lang['bbcode_textcolor'] = "Schriftfarb";
	$lang['bbcode_help_size'] = "Schriftgr&ouml;ssi";
	$lang['smileys'] = "Smilies:";
	$lang['sendmail_admin_title'] = "Neue G&auml;stebuechitrag vo '{NAME}'";
	$lang['sendmail_user_title'] = "Ihre Itrag auf {DOMAIN}";

	// strings of email.php
	$lang['email_name'] = "Ihre Name:";
	$lang['email_email'] = "Ihres eMail:";
	$lang['email_message'] = "Ihri Nachricht:";
	$lang['email_sent_to'] = "Die eMail wird gschickt a:";
	$lang['email_send'] = "Abs&auml;nde";
	$lang['email_caption'] = "eMail von '{NAME}' &uuml;ber das G&auml;stebuch von {DOMAIN}";
	$lang['email_sender'] = "Absender:";
	$lang['email_receiver'] = "Empf&auml;nger:";
	$lang['email_from'] = "&uuml;ber:";
	$lang['email_sendcopytome'] = "Ich m&ouml;chti e Kopie vo dem eMail &uuml;bercho.";
	$lang['email_success'] = "Ihri eMail isch erfolgrich a de Benutzer verschickt worde.";
	$lang['email_fail'] = "Die eMail h&auml;t n&ouml;d verschickt werde ch&ouml;ne. M&ouml;glicherwis git's es Problem mit em Mailserver.";
?>
